//funkcje pobierajace elementy mapy ajax'em

var ajax_actions = {
    ajax_handler: null, //uchwyt do obiektu ajax request

    prev_loaded_subcategory_list: new Array(),
    prev_loaded_objects_on_map: new Array(),
    prev_loaded_subcategories_on_map: new Array(),

    subcategory_el: 'subkategoria_',
    subcategory_list_el: 'subkategoria_lista_',

    /**
     * Funkcja pobierajaca liste obiektow, oraz ich lokalizacje na mapie wraz z opisem, ikonkami itd.
     * @param {Number} subkategoria_id - subkategoria z ktorej wyciagamy liste obiektow
     * @param {String} list_url - link do akcji ktora wyciaga liste obiektow do menu
     * @param {String} icons_url - link do akcji ktora wyciaga obiekty na mape
     */
    checkObjects: function(subkategoria_id, list_url, icons_url) {
        //sprawdzam czy subkategoria jest juz wczytana na mapie
        if(!gmap_user.subcategories_on_map[subkategoria_id]) {
            if(!this.prev_loaded_subcategories_on_map[subkategoria_id]) { //subkategoria jeszcze nie wczytana
                this.getSubcategoryList(subkategoria_id, list_url, icons_url);
            } else { //subkategoria juz byla wczytana przenosimy do tablicy ktora trzyma subkategorie na mapaie i odswiezamy widok
                this.showSubcategoryList(subkategoria_id);
                gmap_user.subcategories_on_map[subkategoria_id] = this.prev_loaded_subcategories_on_map[subkategoria_id];
                this.refreshCategoryOnMap();
            }
        } else { //kategoria juz jest wczytana, zwijamy liste obiektow i usuwamy obiekty z mapy
            this.hideSubcategoryList(subkategoria_id);
            this.removeCategoryFromMap(subkategoria_id);
        }
    },

    showSubcategoryList: function(subcategory_id) {
        //chowamy liste i kasujemy cookie o odpowiedniej nazwie np. subkategoria_lista_1
        var id_to_catch = this.subcategory_list_el+subcategory_id;
        var element = $(id_to_catch);
        if(element) {
            element.show();
            sCookie(id_to_catch, true, 365);

            //dodaje styl zaznaczenia rozwinietej subkategorii
            var subcategory_name = $(this.subcategory_el+subcategory_id)
            if(subcategory_name) {
                subcategory_name.removeClassName('menu_level_sub');
                subcategory_name.addClassName('menu_level_sub_selected');
            }
        }
    },

    hideSubcategoryList: function(subcategory_id) {
        //chowamy liste i kasujemy cookie o odpowiedniej nazwie np. subkategoria_lista_1
        var id_to_catch = this.subcategory_list_el+subcategory_id;
        var element = $(id_to_catch);
        if(element) {
            element.hide();
            sCookie(id_to_catch,'',-1);

            //usuwam styl zaznaczenia rozwinietej subkategorii
            var subcategory_name = $(this.subcategory_el+subcategory_id)
            if(subcategory_name) {
                subcategory_name.removeClassName('menu_level_sub_selected');
                subcategory_name.addClassName('menu_level_sub');
            }
        }
    },

    getSubcategoryList: function(subcategory_id, icons_url, list_url) {
        gmap_user.subcategories_on_map[subcategory_id] = null; //new Array();
        //pokazujemy wskaznik trwajacej operacji
        var ajax_loader = $('wait');
        if(ajax_loader) {
            ajax_loader.show();
        }

        //wczytujemy ikony na mape
        new Ajax.Request(icons_url, {
            asynchronous: false,
            evalScripts: false,
            method: 'get',

            onSuccess: function(response) {
                var icons_list = response.responseJSON;
                
                var categories = icons_list.cats;
                categories._each(function(category) {
                    gmap_user.subcategories_on_map[category.id] = category;
                });
                ajax_actions.refreshCategoryOnMap();
            },
            onFailure: function(response) {
                alert('Błąd: '+response.status+' '+response.statusText)
            }
        });

        //sprawdzam czy w widoku wystepuje lista menu z subkategoriami, jezeli tak aktualizuje ja
        var id_to_update = this.subcategory_list_el+subcategory_id;
        var element = $(id_to_update);
        if(element) {
            //wczytujemy liste obiektow do menu
            this.ajax_handler = new Ajax.Request(list_url, {
                asynchronous: false,
                evalScripts: false,
                method: 'get',
                onSuccess: function(response){
                    element.update(response.responseText);
                    ajax_actions.showSubcategoryList(subcategory_id);
                },
                onFailure: function(response) {
                    alert('Błąd: '+response.status+' '+response.statusText)
                }
            });
        }
        //ukrywamy wskaznik trwajacej operacji
        if(ajax_loader) {
            //trzeba wrzucic opoznienie bo czasami szybciej nastepuje wylaczenie elementu niz wlaczenie
            Element.hide.delay(0.5, 'wait');
        }
    },

    removeCategoryFromMap: function(subcategory_id) {
        //przenosze wczytana liste obiektow do tablicy przechowujacej obiekty raz wczytane
        this.prev_loaded_subcategories_on_map[subcategory_id] = gmap_user.subcategories_on_map[subcategory_id];
        //gmap_user.subcategories_on_map.splice(subcategory_id, 1); //to usuwa klucz i nastepny przenumerowuje reszte kluczy
        delete gmap_user.subcategories_on_map[subcategory_id];
        this.refreshCategoryOnMap();
    },

    refreshCategoryOnMap: function() {
        marker_manager.clearMarkers();
        lines_manager.clearLines();
        polygons_manager.clearPolys();

        gmap_user.subcategories_on_map._each( function(subcategory) {
            //dodaje markery na mape
            //debugger;
            
            if (typeof (subcategory) == 'object') {
                if(!subcategory.empty_array) {
                    if (typeof (subcategory.places) == 'object') { //musi byc ze wzgledu na IE
                        if (subcategory.places.length) {
                            marker_manager.makeMarkers(subcategory);
                        }
                    }

                    //dodaje linie na mape
                    if (typeof (subcategory.lines) == 'object') { //musi byc ze wzgledu na IE
                        if (subcategory.lines.length) {
                            lines_manager.makeLines(subcategory);
                        }
                    }

                    //dodaje polygony na mape
                    if (typeof (subcategory.polys) == 'object') { //musi byc ze wzgledu na IE
                        if (subcategory.polys.length) {
                            polygons_manager.makePolys(subcategory);
                        }
                    }
                }
            }
        });
    },

    radius_search: function (form) {
        var params = Form.serialize(form);
        var link = form.link.value;
        new Ajax.Request(link, {
                asynchronous: true,
                evalScripts: false,
                method: 'post',
                parameters : params,
                onSuccess : function(response) {
                    if (response.status == 200) {
                        var icons_list = response.responseJSON;
                        if (icons_list.count == 0) {
                            alert("Brak Wyników!");
                        } else {
                            gmap_user.clearMap();
                            var categories = icons_list.cats;
                            categories._each(function(category) {
                                gmap_user.subcategories_on_map[category.id] = category;
                            });
                            ajax_actions.refreshCategoryOnMap();
                        }
                    }
                },
                onFailure: function(response) {
                    alert('Błąd: '+response.status+' '+response.statusText)
                }
        });
    }
}