/*
 * Wymagane pliki: geo.js
 */

var map_functions = {
    map: null,
    lineLayer: new Array(),
    lineCounter: new Number(0),
    polygonLayer: new Array(),
    polygonCounter: new Number(0),

    lineListener: null,
    polygonListener: null,
    coordsListener: null,
    linkListener: null,
    
    setMap: function(map_handler) {
        if(this.map==null) {
            this.map = map_handler;
        }
    },

    getMap: function() {
        return map_functions.map;
    },

    drawLineLength: function(lineColor) {
        if(this.lineListener!=null) {
            GEvent.removeListener(map_functions.lineListener);
            map_functions.lineListener = null;
            map_functions.getMap().removeOverlay(map_functions.lineLayer[map_functions.lineCounter]);
        } else {
            this.stopPrototypeLisener();
            if(!lineColor) {
                lineColor = "#007000";
            }
            this.setMap(map);
            var line = new GPolyline([], lineColor, 3, 1);

            this.lineLayer[++this.lineCounter] = line;
            this.getMap().addOverlay(this.lineLayer[this.lineCounter]);

            lineOptions = {};
            line.enableDrawing(lineOptions);

            this.lineListener = GEvent.addListener(line, "endline", function() {
                var length = line.getLength();
                if(length!=0) {
                    length=roundVal((length/1000),2);
                }
                alert("Odległość między punktem początkowym, a końcowym wynosi: "+length+" km");
                map_functions.getMap().removeOverlay(map_functions.lineLayer[map_functions.lineCounter]);
            });
        }
        return 0;
    },

    drawPolygonArea: function(lineColor,bgColor) {
        if(this.polygonListener!=null) {
            GEvent.removeListener(map_functions.polygonListener);
            map_functions.polygonListener = null;
            map_functions.getMap().removeOverlay(map_functions.polygonLayer[map_functions.polygonCounter]);
        } else {
            this.stopPrototypeLisener();
            if(!lineColor) {
                lineColor = "#007000";
            }
            if(!bgColor) {
                bgColor = "#09d108";
            }
            this.setMap(map);
            var polygon = new GPolygon([], lineColor, 2, 1, bgColor, 0.4);

            this.polygonLayer[++this.polygonCounter] = polygon;
            this.getMap().addOverlay(this.polygonLayer[this.polygonCounter]);
            polygon.enableDrawing();

            this.polygonListener = GEvent.addListener(polygon, "endline", function() {
                var area = polygon.getArea();
                if(area!=0) {
                    area=roundVal((area/1000000),2);
                }

                alert("Powierzchnia narysowanego obszaru: "+area+" km^2");
                map_functions.getMap().removeOverlay(map_functions.polygonLayer[map_functions.polygonCounter]);
            });
        }
        return 0;
    },

    getCoords: function() {
        this.setMap(map);
        if(this.coordsListener!=null) { //usuwam listenera w przypadku klikniecia
            GEvent.removeListener(map_functions.coordsListener);
            map_functions.coordsListener = null;
        } else {
            alert("Kliknij na mapę aby pobrać współrzędne geograficzne punktu");
            this.coordsListener = GEvent.addListener(this.getMap(), "click", function(a,b) {
                //var y = Geo.toDMS(b.y,'dms',3);  //dlugosc
                //var x = Geo.toDMS(b.x,'dms',3);  //szerokosc

                //dms
                var lat = Geo.toLat(b.y,'dms',3); //szerokosc
                var lon = Geo.toLon(b.x,'dms',3); //dlugosc
                
                //dziesietnie
                var decLat = roundVal(b.y,5)+" "+(b.y<0 ? 'S' : 'N'); //szerokosc
                var decLon = roundVal(b.x,5)+" "+(b.x<0 ? 'W' : 'E'); //dlugosc

                var showPuwg = true;    //czy obliczac i wyswietlac wspolrzedne w ukladzie wspolrzednych puwg1992

                var puwg1992 = null;
                var puwgMsg = '';
                if(b.y>=49 && b.y<=55 && b.x>=14 && b.x<=24 && showPuwg) {
                    puwg1992 = wgs84toPuwg1992(b.y,b.x);
                    var puwgMsg_szer = roundVal(puwg1992[0],2)+' N [szerokość]\n';
                    puwgMsg_szer = puwgMsg_szer.replace('.', ',');
                    var puwgMsg_dlug = roundVal(puwg1992[1],2)+' E [długość]';
                    puwgMsg_dlug = puwgMsg_dlug.replace('.', ',');
                    puwgMsg = 'Współrzędne PUWG1992\n'+puwgMsg_szer+puwgMsg_dlug;
                }

                var msg = 'Współrzędne geograficzne:\n\nDziesiętnie\n'+decLat.replace('.', ',')+' [szerokość]\n'+decLon.replace('.', ',')+' [długość]\n\nStopnie\n'+lat.replace('.', ',')+' [szerokość]\n'+lon.replace('.', ',')+' [dlugość]';
                if(showPuwg) {
                    msg = msg+'\n\n'+puwgMsg;
                }
                
                alert(msg);

                GEvent.removeListener(map_functions.coordsListener);
                map_functions.coordsListener = null;
            });
        }
    },

    linkGenerator: function(alertText, text) {
        this.setMap(map);
        if(this.linkListener!=null) {
            GEvent.removeListener(map_functions.linkListener);
            map_functions.linkListener = null;
        } else {
            alert(alertText);
            this.linkListener = GEvent.addListener(this.getMap(), "click", function(a, latlng) {
                if (typeof (latlng) == 'object') {
                    //ustawiam host z protokolem
                    var host = document.location.protocol+'//'+document.location.host+'/';
                    //pobieram cookies od rozwinietych kategorii i subkategorii
                    var cookies = map_functions.getCategoryCookies();

                    var categoryAddon = new String();//"&kategoria=";
                    cookies[0]._each(function(categoryNumber) {
                        categoryAddon += categoryNumber+',';
                    });

                    var subcategoryAddon = new String();//"&subkategoria=";
                    cookies[1]._each(function(subcategoryNumber) {
                        subcategoryAddon += subcategoryNumber+',';
                    });
                    
                    if(categoryAddon=="") {
                        categoryAddon="0";
                    } else {
                        categoryAddon = categoryAddon.slice(0,-1);  //obcinam ostatni przecinek w stringu
                    }

                    if(subcategoryAddon=="") {
                        subcategoryAddon="0";
                    } else {
                        subcategoryAddon = subcategoryAddon.slice(0,-1);  //obcinam ostatni przecinek w stringu
                    }
                    //categoryAddon = escape(categoryAddon);
                    //subcategoryAddon = escape(subcategoryAddon);
                    
                    var z = map_functions.getMap().getZoom();
                    var x = String(latlng.y).replace('.', ',');
                    var y = String(latlng.x).replace('.', ',');
                    x = x.replace('-', '&shy;');
                    y = y.replace('-', '&shy;');
                    var link = host + "permalink/" + x + "/" + y + "/" + z + "/" +categoryAddon+ "/" +subcategoryAddon+".html";

                    var windowOpts = {
                        onCloseFn: function() {
                            GEvent.removeListener(map_functions.linkListener);
                            map_functions.linkListener = null;
                        }
                    };

                    map_functions.getMap().openInfoWindowHtml(latlng, text+"<br/><input class='ginput' value='" + link + "' />",windowOpts);
                }
            });
        }
    },

    /*
     * Funkcja pobiera cookies i wydziela z nich numery kategorii i subkategorii
     * return Array:
     *  [0] - lista numerow kategorii
     *  [1] - lista numerow subkategorii
     */
    getCategoryCookies: function() {
        var kategoria_lista = new Array();
        var subkategoria_lista = new Array();

        var kategoria_pattern=new RegExp('^kategoria_lista_');
        var subkategoria_pattern=new RegExp('^subkategoria_lista_');

        var i,x,y,ARRcookies=document.cookie.split(";");
        for (i=0;i<ARRcookies.length;i++) {
            x=ARRcookies[i].substr(0,ARRcookies[i].indexOf("="));
            y=ARRcookies[i].substr(ARRcookies[i].indexOf("=")+1);
            x=x.replace(/^\s+|\s+$/g,"");

            if(x.match(kategoria_pattern)) {
                kategoria_lista.push(x.replace(kategoria_pattern, ""));
            } else if(x.match(subkategoria_pattern)) {
                subkategoria_lista.push(x.replace(subkategoria_pattern, ""));
            }

        }

        var return_array = new Array();
        return_array.push(kategoria_lista);
        return_array.push(subkategoria_lista);
        
        return return_array;
    },

    stopPrototypeLisener: function() {
        Event.stopObserving(document);
    }
}

function roundVal(val,precision){
    var result = Math.round(val*Math.pow(10,precision))/Math.pow(10,precision);
    return result;
}

