var marker_manager = {
    manager_instance: null,
    manager_type: 'cluster', //'simple', //'cluster',

    //opcja dla marker clusterer
    cluster_max_zoom_level: 17, //17-optymalna wartosc, null,
    cluster_grid_size: 30,//null,

    getManager: function() {
        if(isNull(this.manager_instance)) {
            this.setManager();
        }
        return this.manager_instance;
    },

    setManager: function() {
        switch(this.manager_type) {
            case 'cluster':
                this.manager_instance = new MarkerClusterer(gmap_user.getMap(),[],{
                    maxZoom:    this.cluster_max_zoom_level,
                    gridSize:   this.cluster_grid_size
                });
                GEvent.addListener(gmap_user.getMap(), 'zoomend', function() {
                    marker_manager.getManager().resetViewport();
                });
                GEvent.addListener(gmap_user.getMap(), 'moveend', function() {
                    marker_manager.getManager().resetViewport();
                });
                GEvent.addListener(gmap_user.getMap(), 'dragend', function() {
                    marker_manager.getManager().resetViewport();
                });
            break;

            case 'simple':
            default:
                this.manager_instance =  new MarkerManager(gmap_user.getMap(), {
                    trackMarkers: true //Indicates whether or not a marker manager should track markers' movements. If you wish to move managed markers using the setPoint/setLatLng methods, this option should be set to true. The default value is false.
                });
            break;
        }
    },

    makeMarkers: function(points_list) {
        points_list.places._each(function(point) {
            var position = new GLatLng(point.posn[0], point.posn[1]);

            var opts = {
                icon: marker_manager.createIcon(point.icon, 32),
                title: point.sname,
                transparent: point.icon
            };
            var marker = new GMarker(position, opts);
            marker.item = new Object();
            marker.item.id = point.id;
            //marker.item.point = point; //po co dodawac obiekt wyciagany z bazy do gotowego markera?
            marker.item.izmin = point.izmin;
            marker.item.izmax = point.izmax;
            marker.item.mask = point.mask;
            marker.item.desc = point.desc;
            
            GEvent.addListener(marker, 'click', function() {
                marker_manager.getMarkerDescription(marker);
            });

            gmap_user.markers_array.push(marker); //dodaje marker do tablicy przechowywanej w obiekcie mapy [gmap_user.js]

        });
        this.addMarkersToMap();
    },

    addMarkersToMap: function() {
        this.getManager().clearMarkers(); //czyscimy tablice z markerami w obiekcie managera ikon
        switch(this.manager_type) {
            case 'cluster':
                
                this.getManager().addMarkers(gmap_user.markers_array);
            break;

            case 'simple':
            default:
                this.getManager().addMarkers(gmap_user.markers_array, 6,21);
                //gmap_user.markers_array._each( function(marker) {
                //  manager.addMarker(marker, marker.izmin, marker.izmax);
                //});
            break;
        }
        this.refreshMap();
    },

    refreshMap: function() {
        switch(this.manager_type) {
            case 'cluster':
                this.getManager().resetViewport();
            break;

            case 'simple':
            default:
                this.getManager().refresh();
            break;
        }
    },

    clearMarkers: function() {
        gmap_user.markers_array = new Array();
        this.getManager().clearMarkers();
        this.refreshMap();
    },

    createIcon: function(image, size) {
        if (!size) {
            size = 22;
        }
        var icon = null;
        if (image) {
            icon = new GIcon();
            icon.image = basedir + size + "x" + size + "/" + image;
            icon.iconSize = new GSize(32, 32);
            icon.iconAnchor = new GPoint(11, 11);
            icon.infoWindowAnchor = new GPoint(16, 16);
            icon.infoShadowAnchor = new GPoint(32, 32);
        }
        return icon;
    },

    /**
     * Funkcja pobiera opis kliknietego markera na mapie, tworzy dymek i wypelnia go pobrana trescia
     * @param {Object} marker - GMarker
     */

    getMarkerDescription: function (marker) {
        new Ajax.Request(marker.item.desc, {
            asynchronous: true,
            evalScripts: true,
            method: 'get',
            onLoading : function() {
                var ajax_loader = $('wait');
                if(ajax_loader) {
                    ajax_loader.show();
                }
            },
            onSuccess : function(response) {
                var ajax_loader = $('wait');
                if(ajax_loader) {
                    //trzeba wrzucic opoznienie bo czasami szybciej nastepuje wylaczenie elementu niz wlaczenie
                    Element.hide.delay(0.5, 'wait');
                }

                var window_position = marker.getLatLng();

                var window_opts = {
                    maxContent: response.responseJSON.pelny_opis,
                    maxTitle: marker.item.name
                }
                
                var window_tabs = new Array();
                
                for(var tab_name in response.responseJSON.tabs) {
                    var tab = response.responseJSON.tabs[tab_name];
                    window_tabs.push(new GInfoWindowTab(tab.title, tab.content));
                }

                if (typeof (response.responseJSON.tabs) == 'object') { //wersja z zakladkami
                    gmap_user.getMap().openInfoWindowTabsHtml(window_position, window_tabs, window_opts);
                    //gmap_user.getMap().openInfoWindowTabsHtml(window_position, window_tabs, maxopts);
                } else { //wersja bez zakladek
                    gmap_user.getMap().openInfoWindowHtml(window_position, response.responseJSON.pelny_opis, window_opts);
                }
            },

            onFailure: function(response) {
                alert('Błąd: '+response.status+' '+response.statusText)
            }
        });
    }
}